@@ -9,6 +9,7 @@ from telescope_sdk.utils import (
     convert_country_name_to_iso_code,
     convert_date_string_to_datetime_string,
     get_current_datetime_aws_format,
+    normalize_url
 )
 
 
@@ -141,12 +142,11 @@ class Person(IngestedDataType):
         country = pdl_input.get('location_country')
         job_start_date = pdl_input.get('job_start_date')
         job_last_updated = pdl_input.get('job_last_updated')
-        linkedin_url = pdl_input.get('linkedin_url')
-        linkedin_url = ("https://www." + linkedin_url) if not linkedin_url.startswith("https://www.") else linkedin_url
+        linkedin_url = normalize_url(pdl_input.get('linkedin_url'))
 
         return Person(
             # normalize string for id - empty spaces and leading and trailing /
-            id=md5(linkedin_url.replace(" ", "").strip("/").encode()).hexdigest(),
+            id=md5(linkedin_url.encode()).hexdigest(),
             source=Source.PDL,
             version=0,
             created_at=get_current_datetime_aws_format(),
